@@ -13,7 +13,7 @@ has workers =>
   sub { $_[0]->mango->db->collection($_[0]->prefix . '.workers') };
 
 sub dequeue {
-  my ($self, $id) = @_;
+  my ($self, $oid) = @_;
 
   my $doc = {
     query => {
@@ -23,10 +23,8 @@ sub dequeue {
     },
     fields => {args     => 1, task => 1},
     sort   => {priority => -1},
-    update => {
-      '$set' =>
-        {started => bson_time, state => 'active', worker => bson_oid($id)}
-    },
+    update =>
+      {'$set' => {started => bson_time, state => 'active', worker => $oid}},
     new => 1
   };
 
@@ -72,9 +70,8 @@ sub register_worker {
 }
 
 sub remove_job {
-  my ($self, $id) = @_;
-  my $doc = {_id => bson_oid($id),
-    state => {'$in' => [qw(failed finished inactive)]}};
+  my ($self, $oid) = @_;
+  my $doc = {_id => $oid, state => {'$in' => [qw(failed finished inactive)]}};
   return !!$self->jobs->remove($doc)->{n};
 }
 
@@ -100,10 +97,9 @@ sub repair {
 sub reset { $_->options && $_->drop for $_[0]->workers, $_[0]->jobs }
 
 sub restart_job {
-  my ($self, $id) = @_;
+  my ($self, $oid) = @_;
 
-  my $query
-    = {_id => bson_oid($id), state => {'$in' => [qw(failed finished)]}};
+  my $query = {_id => $oid, state => {'$in' => [qw(failed finished)]}};
   my $update = {
     '$inc' => {restarts  => 1},
     '$set' => {restarted => bson_time, state => 'inactive'},
@@ -126,11 +122,9 @@ sub stats {
   return $stats;
 }
 
-sub unregister_worker { shift->workers->remove({_id => bson_oid(shift)}) }
+sub unregister_worker { shift->workers->remove({_id => shift}) }
 
-sub worker_info {
-  $_[0]->_worker_info($_[0]->workers->find_one(bson_oid($_[1])));
-}
+sub worker_info { $_[0]->_worker_info($_[0]->workers->find_one($_[1])) }
 
 sub _job_info {
   my $self = shift;
@@ -142,7 +136,7 @@ sub _job_info {
     delayed   => $job->{delayed} ? $job->{delayed}->to_epoch : undef,
     error     => $job->{error},
     finished  => $job->{finished} ? $job->{finished}->to_epoch : undef,
-    id        => "$job->{_id}",
+    id        => $job->{_id},
     priority  => $job->{priority},
     restarted => $job->{restarted} ? $job->{restarted}->to_epoch : undef,
     restarts => $job->{restarts} // 0,
@@ -163,11 +157,11 @@ sub _list {
 }
 
 sub _update {
-  my ($self, $fail, $id, $err) = @_;
+  my ($self, $fail, $oid, $err) = @_;
 
   my $update = {finished => bson_time, state => $fail ? 'failed' : 'finished'};
   $update->{error} = $err if $fail;
-  my $query = {_id => bson_oid($id), state => 'active'};
+  my $query = {_id => $oid, state => 'active'};
   return !!$self->jobs->update($query, {'$set' => $update})->{n};
 }
 
@@ -179,7 +173,7 @@ sub _worker_info {
     = $self->jobs->find({state => 'active', worker => $worker->{_id}});
   return {
     host    => $worker->{host},
-    id      => "$worker->{_id}",
+    id      => $worker->{_id},
     jobs    => [map { $_->{_id} } @{$cursor->all}],
     pid     => $worker->{pid},
     started => $worker->{started}->to_epoch
